==> plantuml-libs-7.1.0.tgz: package/distribution/eip-1/MessagingChannels/PublishSubscribeChannel.md <==
# PublishSubscribeChannel


```text
eip-1/MessagingChannels/PublishSubscribeChannel
```

```text
include('eip-1/MessagingChannels/PublishSubscribeChannel')
```



| Illustration | PublishSubscribeChannel | PublishSubscribeChannelGroup |
| :---: | :---: | :---: |
| ![illustration for Illustration](../../eip-1/MessagingChannels/PublishSubscribeChannel.png) | ![illustration for PublishSubscribeChannel](../../eip-1/MessagingChannels/PublishSubscribeChannel.Local.png) | ![illustration for PublishSubscribeChannelGroup](../../eip-1/MessagingChannels/PublishSubscribeChannelGroup.Local.png) |




## PublishSubscribeChannel

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('eip-1/bootstrap')

' loads the Item which embeds the element PublishSubscribeChannel
include('eip-1/MessagingChannels/PublishSubscribeChannel')

' renders the element
PublishSubscribeChannel('PublishSubscribeChannel', 'Publish Subscribe Channel', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('eip-1/bootstrap')

' loads the Item which embeds the element PublishSubscribeChannel
include('eip-1/MessagingChannels/PublishSubscribeChannel')

' renders the element
PublishSubscribeChannel('PublishSubscribeChannel', 'Publish Subscribe Channel', 'an optional tech label')
@enduml
```

## PublishSubscribeChannelGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('eip-1/bootstrap')

' loads the Item which embeds the element PublishSubscribeChannelGroup
include('eip-1/MessagingChannels/PublishSubscribeChannel')

' renders the element
PublishSubscribeChannelGroup('PublishSubscribeChannelGroup', 'Publish Subscribe Channel Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('eip-1/bootstrap')

' loads the Item which embeds the element PublishSubscribeChannelGroup
include('eip-1/MessagingChannels/PublishSubscribeChannel')

' renders the element
PublishSubscribeChannelGroup('PublishSubscribeChannelGroup', 'Publish Subscribe Channel Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/eip-1/MessagingChannels/PublishSubscribeChannel.md <==
# PublishSubscribeChannel


```text
eip-1/MessagingChannels/PublishSubscribeChannel
```

```text
include('eip-1/MessagingChannels/PublishSubscribeChannel')
```



| Illustration | PublishSubscribeChannel | PublishSubscribeChannelGroup |
| :---: | :---: | :---: |
| ![illustration for Illustration](../../eip-1/MessagingChannels/PublishSubscribeChannel.png) | ![illustration for PublishSubscribeChannel](../../eip-1/MessagingChannels/PublishSubscribeChannel.Local.png) | ![illustration for PublishSubscribeChannelGroup](../../eip-1/MessagingChannels/PublishSubscribeChannelGroup.Local.png) |




## PublishSubscribeChannel

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('eip-1/bootstrap')

' loads the Item which embeds the element PublishSubscribeChannel
include('eip-1/MessagingChannels/PublishSubscribeChannel')

' renders the element
PublishSubscribeChannel('PublishSubscribeChannel', 'Publish Subscribe Channel', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('eip-1/bootstrap')

' loads the Item which embeds the element PublishSubscribeChannel
include('eip-1/MessagingChannels/PublishSubscribeChannel')

' renders the element
PublishSubscribeChannel('PublishSubscribeChannel', 'Publish Subscribe Channel', 'an optional tech label', 'an optional description')
@enduml
```

## PublishSubscribeChannelGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('eip-1/bootstrap')

' loads the Item which embeds the element PublishSubscribeChannelGroup
include('eip-1/MessagingChannels/PublishSubscribeChannel')

' renders the element
PublishSubscribeChannelGroup('PublishSubscribeChannelGroup', 'Publish Subscribe Channel Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('eip-1/bootstrap')

' loads the Item which embeds the element PublishSubscribeChannelGroup
include('eip-1/MessagingChannels/PublishSubscribeChannel')

' renders the element
PublishSubscribeChannelGroup('PublishSubscribeChannelGroup', 'Publish Subscribe Channel Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
